DensityOfStates
========================

The :class:`pyprocar.core.DensityOfStates` class is used to store and manipulate density of states information. 
Density of states 1d numpy array of energy, (n_energy,n_spin) total densities and projections at each energy.
See :ref:`dos` for further details.

.. autosummary::
   :toctree: _autosummary

   pyprocar.core.DensityOfStates